"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSubscriptionsClient = exports.createResourcesClient = exports.createStorageClient = void 0;
const createAzureClient_1 = require("./createAzureClient");
// Lazy-load @azure packages to improve startup performance.
// NOTE: The client is the only import that matters, the rest of the types disappear when compiled to JavaScript
function createStorageClient(context) {
    return __awaiter(this, void 0, void 0, function* () {
        if ((0, createAzureClient_1.parseClientContext)(context).isCustomCloud) {
            return (0, createAzureClient_1.createAzureClient)(context, (yield Promise.resolve().then(() => require('@azure/arm-storage-profile-2020-09-01-hybrid'))).StorageManagementClient);
        }
        else {
            return (0, createAzureClient_1.createAzureClient)(context, (yield Promise.resolve().then(() => require('@azure/arm-storage'))).StorageManagementClient);
        }
    });
}
exports.createStorageClient = createStorageClient;
function createResourcesClient(context) {
    return __awaiter(this, void 0, void 0, function* () {
        if ((0, createAzureClient_1.parseClientContext)(context).isCustomCloud) {
            return (0, createAzureClient_1.createAzureClient)(context, (yield Promise.resolve().then(() => require('@azure/arm-resources-profile-2020-09-01-hybrid'))).ResourceManagementClient);
        }
        else {
            return (0, createAzureClient_1.createAzureClient)(context, (yield Promise.resolve().then(() => require('@azure/arm-resources'))).ResourceManagementClient);
        }
    });
}
exports.createResourcesClient = createResourcesClient;
function createSubscriptionsClient(context) {
    return __awaiter(this, void 0, void 0, function* () {
        return (0, createAzureClient_1.createAzureSubscriptionClient)(context, (yield Promise.resolve().then(() => require('@azure/arm-resources-subscriptions'))).SubscriptionClient);
    });
}
exports.createSubscriptionsClient = createSubscriptionsClient;
//# sourceMappingURL=clients.js.map