"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.NoResourceFoundError = exports.NotImplementedError = exports.GoBackError = exports.UserCancelledError = void 0;
const localize_1 = require("./localize");
class UserCancelledError extends Error {
    constructor(stepName) {
        super((0, localize_1.localize)('userCancelledError', 'Operation cancelled.'));
        this.stepName = stepName;
    }
}
exports.UserCancelledError = UserCancelledError;
class GoBackError extends Error {
    constructor() {
        super((0, localize_1.localize)('backError', 'Go back.'));
    }
}
exports.GoBackError = GoBackError;
class NotImplementedError extends Error {
    constructor(methodName, obj) {
        super((0, localize_1.localize)('notImplementedError', '"{0}" is not implemented on "{1}".', methodName, obj.constructor.name));
    }
}
exports.NotImplementedError = NotImplementedError;
class NoResourceFoundError extends Error {
    constructor(context) {
        if (context && context.noItemFoundErrorMessage) {
            super(context.noItemFoundErrorMessage);
            context.errorHandling.suppressReportIssue = true;
        }
        else {
            super((0, localize_1.localize)('noResourcesError', 'No matching resources found.'));
        }
    }
}
exports.NoResourceFoundError = NoResourceFoundError;
//# sourceMappingURL=errors.js.map