"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.appendExtensionUserAgent = exports.addExtensionUserAgent = void 0;
const getPackageInfo_1 = require("./getPackageInfo");
/**
 * Adds a user agent specific to the VS Code extension, of the form `${extensionName}/${extensionVersion}`
 */
function addExtensionUserAgent(client) {
    client.addUserAgentInfo(getExtensionUserAgent());
}
exports.addExtensionUserAgent = addExtensionUserAgent;
function getExtensionUserAgent() {
    const { extensionName, extensionVersion } = (0, getPackageInfo_1.getPackageInfo)();
    return `${extensionName}/${extensionVersion}`;
}
function appendExtensionUserAgent(existingUserAgent) {
    const extensionUserAgent = getExtensionUserAgent();
    existingUserAgent || (existingUserAgent = extensionUserAgent);
    if (existingUserAgent.includes(extensionUserAgent)) {
        return existingUserAgent;
    }
    else {
        return `${existingUserAgent} ${extensionUserAgent}`;
    }
}
exports.appendExtensionUserAgent = appendExtensionUserAgent;
//# sourceMappingURL=extensionUserAgent.js.map