"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPackageInfo = void 0;
const fs = require("fs");
const extensionVariables_1 = require("./extensionVariables");
let packageInfo;
function getPackageInfo(ctx) {
    if (!packageInfo) {
        if (!ctx) {
            ctx = extensionVariables_1.ext.context;
        }
        const packageJson = JSON.parse(fs.readFileSync(ctx.asAbsolutePath('package.json')).toString());
        const extensionName = packageJson.name;
        const extensionVersion = packageJson.version;
        const aiKey = packageJson.aiKey;
        const publisher = packageJson.publisher;
        const bugsUrl = !packageJson.bugs ? undefined :
            typeof packageJson.bugs === 'string' ? packageJson.bugs :
                packageJson.bugs.url;
        if (!aiKey) {
            throw new Error('Extension\'s package.json is missing aiKey');
        }
        if (!extensionName) {
            throw new Error('Extension\'s package.json is missing name');
        }
        if (!publisher) {
            throw new Error('Extension\'s package.json is missing publisher');
        }
        if (!extensionVersion) {
            throw new Error('Extension\'s package.json is missing version');
        }
        const extensionId = `${packageJson.publisher}.${packageJson.name}`;
        packageInfo = { extensionName, extensionVersion, aiKey, extensionId, bugsUrl };
    }
    return packageInfo;
}
exports.getPackageInfo = getPackageInfo;
//# sourceMappingURL=getPackageInfo.js.map