"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerCommand = void 0;
const vscode_1 = require("vscode");
const callWithTelemetryAndErrorHandling_1 = require("./callWithTelemetryAndErrorHandling");
const extensionVariables_1 = require("./extensionVariables");
const addTreeItemValuesToMask_1 = require("./tree/addTreeItemValuesToMask");
const AzExtTreeItem_1 = require("./tree/AzExtTreeItem");
function registerCommand(commandId, callback, debounce, telemetryId) {
    let lastClickTime; /* Used for debounce */
    extensionVariables_1.ext.context.subscriptions.push(vscode_1.commands.registerCommand(commandId, (...args) => __awaiter(this, void 0, void 0, function* () {
        if (debounce) { /* Only check for debounce if registered command specifies */
            if (debounceCommand(debounce, lastClickTime)) {
                return;
            }
            lastClickTime = Date.now();
        }
        // eslint-disable-next-line @typescript-eslint/no-unsafe-return
        return yield (0, callWithTelemetryAndErrorHandling_1.callWithTelemetryAndErrorHandling)(telemetryId || commandId, (context) => {
            if (args.length > 0) {
                const firstArg = args[0];
                if (firstArg instanceof AzExtTreeItem_1.AzExtTreeItem) {
                    context.telemetry.properties.contextValue = firstArg.contextValue;
                }
                else if (firstArg instanceof vscode_1.Uri) {
                    context.telemetry.properties.contextValue = 'Uri';
                }
                for (const arg of args) {
                    if (arg instanceof AzExtTreeItem_1.AzExtTreeItem) {
                        (0, addTreeItemValuesToMask_1.addTreeItemValuesToMask)(context, arg, 'command');
                    }
                }
            }
            // eslint-disable-next-line @typescript-eslint/no-unsafe-return
            return callback(context, ...args);
        });
    })));
}
exports.registerCommand = registerCommand;
function debounceCommand(debounce, lastClickTime) {
    if (lastClickTime && lastClickTime + debounce > Date.now()) {
        return true;
    }
    return false;
}
//# sourceMappingURL=registerCommand.js.map