"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerReportIssueCommand = exports.cacheIssueForCommand = void 0;
const dayjs = require("dayjs");
// eslint-disable-next-line import/no-internal-modules
const relativeTime = require("dayjs/plugin/relativeTime");
const localize_1 = require("./localize");
const registerCommand_1 = require("./registerCommand");
const reportAnIssue_1 = require("./reportAnIssue");
const nonNull_1 = require("./utils/nonNull");
dayjs.extend(relativeTime);
let cachedIssues;
function cacheIssueForCommand(issue) {
    if (cachedIssues) {
        cachedIssues.push(issue);
        // Remove any duplicate issues
        cachedIssues = cachedIssues.filter(i => {
            return i === issue || i.callbackId !== issue.callbackId || i.error.message !== issue.error.message;
        });
        const maxIssues = 50;
        if (cachedIssues.length > maxIssues) {
            cachedIssues.shift();
        }
    }
}
exports.cacheIssueForCommand = cacheIssueForCommand;
function registerReportIssueCommand(commandId) {
    cachedIssues = [];
    (0, registerCommand_1.registerCommand)(commandId, (context) => __awaiter(this, void 0, void 0, function* () {
        context.errorHandling.suppressDisplay = true;
        context.errorHandling.suppressReportIssue = true;
        cachedIssues = (0, nonNull_1.nonNullValue)(cachedIssues, 'cachedIssues');
        if (cachedIssues.length === 0) {
            yield (0, reportAnIssue_1.reportAnIssue)(undefined);
        }
        else {
            const picks = cachedIssues.reverse().map(i => {
                return {
                    label: i.error.message,
                    description: i.error.errorType,
                    detail: `${i.callbackId} - ${dayjs(i.time).fromNow()}`,
                    data: i
                };
            });
            picks.unshift({
                label: (0, localize_1.localize)('emptyIssue', '$(keyboard) Manually enter error'),
                data: undefined
            });
            const placeHolder = (0, localize_1.localize)('selectError', 'Select the error you would like to report');
            const issue = (yield context.ui.showQuickPick(picks, { placeHolder, stepName: 'reportIssue', suppressPersistence: true })).data;
            yield (0, reportAnIssue_1.reportAnIssue)(issue);
        }
    }));
}
exports.registerReportIssueCommand = registerReportIssueCommand;
//# sourceMappingURL=registerReportIssueCommand.js.map