"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.showWarningMessage = void 0;
const vscode_1 = require("vscode");
const DialogResponses_1 = require("../DialogResponses");
const errors_1 = require("../errors");
const localize_1 = require("../localize");
const openUrl_1 = require("../utils/openUrl");
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function showWarningMessage(context, message, ...args) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
        const learnMoreLink = args[0] && args[0].learnMoreLink;
        if (learnMoreLink) {
            args.push(DialogResponses_1.DialogResponses.learnMore);
        }
        const back = { title: (0, localize_1.localize)('back', 'Back') };
        if ((_a = context.ui.wizard) === null || _a === void 0 ? void 0 : _a.showBackButton) {
            args.push(back);
        }
        // eslint-disable-next-line no-constant-condition
        while (true) {
            // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
            const result = yield vscode_1.window.showWarningMessage(message, ...args);
            if (learnMoreLink && result === DialogResponses_1.DialogResponses.learnMore) {
                context.telemetry.properties.learnMoreStep = context.telemetry.properties.lastStep;
                yield (0, openUrl_1.openUrl)(learnMoreLink);
            }
            else if (result === undefined || result === DialogResponses_1.DialogResponses.cancel) {
                throw new errors_1.UserCancelledError();
            }
            else if (result === back) {
                throw new errors_1.GoBackError();
            }
            else {
                return result;
            }
        }
    });
}
exports.showWarningMessage = showWarningMessage;
//# sourceMappingURL=showWarningMessage.js.map