"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AzExtFsExtra = void 0;
const path_1 = require("path");
const vscode_1 = require("vscode");
const parseError_1 = require("../parseError");
var AzExtFsExtra;
(function (AzExtFsExtra) {
    function isDirectory(resource) {
        return __awaiter(this, void 0, void 0, function* () {
            const uri = convertToUri(resource);
            const stats = yield vscode_1.workspace.fs.stat(uri);
            return stats.type === vscode_1.FileType.Directory;
        });
    }
    AzExtFsExtra.isDirectory = isDirectory;
    function isFile(resource) {
        return __awaiter(this, void 0, void 0, function* () {
            const uri = convertToUri(resource);
            const stats = yield vscode_1.workspace.fs.stat(uri);
            return stats.type === vscode_1.FileType.File;
        });
    }
    AzExtFsExtra.isFile = isFile;
    function ensureDir(resource) {
        return __awaiter(this, void 0, void 0, function* () {
            const uri = convertToUri(resource);
            try {
                // if it is a file, then we should create the directory
                if (yield isDirectory(uri))
                    return;
            }
            catch (err) {
                // throws a vscode.FileSystemError is it doesn't exist
                const pError = (0, parseError_1.parseError)(err);
                if (pError && pError.errorType === 'FileNotFound') {
                    // drop down below to create the directory
                }
                else {
                    throw err;
                }
            }
            yield vscode_1.workspace.fs.createDirectory(uri);
        });
    }
    AzExtFsExtra.ensureDir = ensureDir;
    function ensureFile(resource) {
        return __awaiter(this, void 0, void 0, function* () {
            const uri = convertToUri(resource);
            try {
                // file exists so exit
                if (yield isFile(uri))
                    return;
            }
            catch (err) {
                // throws a vscode.FileSystemError is it doesn't exist
                const pError = (0, parseError_1.parseError)(err);
                if (pError && pError.errorType === 'FileNotFound') {
                    const dir = (0, path_1.dirname)(uri.fsPath);
                    yield ensureDir(dir);
                }
                else {
                    throw err;
                }
            }
            yield vscode_1.workspace.fs.writeFile(uri, Buffer.from(''));
        });
    }
    AzExtFsExtra.ensureFile = ensureFile;
    function readFile(resource) {
        return __awaiter(this, void 0, void 0, function* () {
            const uri = convertToUri(resource);
            return (yield vscode_1.workspace.fs.readFile(uri)).toString();
        });
    }
    AzExtFsExtra.readFile = readFile;
    function writeFile(resource, contents) {
        return __awaiter(this, void 0, void 0, function* () {
            const uri = convertToUri(resource);
            yield vscode_1.workspace.fs.writeFile(uri, Buffer.from(contents));
        });
    }
    AzExtFsExtra.writeFile = writeFile;
    function pathExists(resource) {
        return __awaiter(this, void 0, void 0, function* () {
            let stats;
            const uri = convertToUri(resource);
            try {
                stats = yield vscode_1.workspace.fs.stat(uri);
            }
            catch ( /*ignore*/_a) { /*ignore*/ }
            return !!stats;
        });
    }
    AzExtFsExtra.pathExists = pathExists;
    function convertToUri(resource) {
        return typeof resource === 'string' ? vscode_1.Uri.file(resource) : resource;
    }
})(AzExtFsExtra = exports.AzExtFsExtra || (exports.AzExtFsExtra = {}));
//# sourceMappingURL=AzExtFsExtra.js.map