"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.md in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.nonNullOrEmptyValue = exports.nonNullValue = exports.nonNullProp = void 0;
const util_1 = require("util");
/**
 * Retrieves a property by name from an object and checks that it's not null and not undefined.  It is strongly typed
 * for the property and will give a compile error if the given name is not a property of the source.
 */
function nonNullProp(source, name) {
    const value = source[name];
    return nonNullValue(value, name);
}
exports.nonNullProp = nonNullProp;
/**
 * Validates that a given value is not null and not undefined.
 */
function nonNullValue(value, propertyNameOrMessage) {
    if ((0, util_1.isNullOrUndefined)(value)) {
        throw new Error('Internal error: Expected value to be neither null nor undefined'
            + (propertyNameOrMessage ? `: ${propertyNameOrMessage}` : ''));
    }
    return value;
}
exports.nonNullValue = nonNullValue;
/**
 * Validates that a given string is not null, undefined, nor empty
 */
function nonNullOrEmptyValue(value, propertyNameOrMessage) {
    if (!value) {
        throw new Error('Internal error: Expected value to be neither null, undefined, nor empty'
            + (propertyNameOrMessage ? `: ${propertyNameOrMessage}` : ''));
    }
    return value;
}
exports.nonNullOrEmptyValue = nonNullOrEmptyValue;
//# sourceMappingURL=nonNull.js.map